@@ -13,9 +13,9 @@ class AttckObject(object):
     """
 
     _RELATIONSHIPS = None
-    generated_attck_json = Configuration.get_data(Configuration.config_data.get('generated_attck_json'))
-    nist_controls_json = Configuration.get_data(Configuration.config_data.get('nist_controls_json'))['objects']
-    generated_nist_json = Configuration.get_data(Configuration.config_data.get('generated_nist_json'))
+    generated_attck_json = Configuration.get_data('generated_attck_json')
+    nist_controls_json = Configuration.get_data('nist_controls_json')['objects']
+    generated_nist_json = Configuration.get_data('generated_nist_json')
 
     def __init__(self, **kwargs):
         """
@@ -28,6 +28,7 @@ class AttckObject(object):
         self.id = self._set_id(kwargs)
         self.name = self._set_attribute(kwargs, 'name')
         self.alias = self.__set_alias(kwargs)
+        self.aliases = self.alias
         self.description = self._set_attribute(kwargs, 'description')
         self.reference = self._set_reference(kwargs)
         self.created = self._set_attribute(kwargs, 'created')
@@ -123,6 +124,17 @@ class AttckObject(object):
         except:
             return None
 
+    def _create_data_sources_dict(self, obj):
+        return_dict = {}
+        if isinstance(obj, list):
+            for item in obj:
+                if ':' in item:
+                    data_source, data_component = item.split(':')
+                    if data_source not in return_dict:
+                        return_dict[data_source] = []
+                    return_dict[data_source].append(data_component.strip())
+        return return_dict
+
     def _set_list_items(self, obj, list_name):
         """
         Private method used by child classes and normalizes list items
