@@ -5,9 +5,11 @@ from .tools import AttckTools
 from .mitigation import AttckMitigation
 from .tactic import AttckTactic
 from .control import AttckControl
+from .datasource import AttckDataSource
 from ..configuration import Configuration
 
 
+
 class Enterprise(object):
 
     """An interface to the Enterprise MITRE ATT&CK Framework.
@@ -266,7 +268,12 @@ class Enterprise(object):
     __tools = []
     __malwares = []
     __controls = []
-    
+    __data_sources = []
+    __ENTERPRISE_GENERATED_DATA_JSON = None
+    __nist_controls_json = Configuration.get_data('nist_controls_json')['objects']
+    __attck = Configuration.get_data('enterprise_attck_json')
+
+
     def __init__(self, nested_subtechniques=True):
         """
         Sets standard properties that are found in all child classes
@@ -277,9 +284,6 @@ class Enterprise(object):
             nested_subtechniques (bool) -- Determines if nested subtechniques will
             be used or not. This is passed from attck class
         """
-        self.__ENTERPRISE_GENERATED_DATA_JSON = None
-        self.__nist_controls_json = Configuration.get_data(Configuration.config_data.get('nist_controls_json'))['objects']
-        self.__attck = Configuration.get_data(Configuration.config_data.get('enterprise_attck_json'))
         self.__nested_subtechniques = nested_subtechniques
 
     @property
@@ -310,6 +314,20 @@ class Enterprise(object):
                     self.__controls.append(AttckControl(attck_obj=self.__attck, **control))
         return self.__controls
 
+    @property
+    def data_sources(self):
+        """
+        Creates AttckDataSource objects
+
+        Returns:
+            (AttckDataSource) -- Returns a list of AttckDataSource objects
+        """
+        if not self.__data_sources:
+            for source in self.__attck['objects']:
+                if source['type'] == 'x-mitre-data-source':
+                    self.__data_sources.append(AttckDataSource(attck_obj=self.__attck, **source))
+        return self.__data_sources
+
     @property
     def tactics(self):
         """
@@ -396,6 +414,18 @@ class Enterprise(object):
                                             technique.subtechniques = AttckTechnique(attck_obj=self.__attck, **item)
         return self.__techniques
 
+    @property
+    def search(self):
+        from .search import Search
+        return Search(
+            actors=self.actors,
+            malwares=self.malwares,
+            mitigations=self.mitigations,
+            tactics=self.tactics,
+            techniques=self.techniques,
+            tools=self.tools
+        )
+
     def search_commands(self, search_term, json=False):
         """
         Search external datasets for potential commands using a search term
@@ -410,10 +440,9 @@ class Enterprise(object):
         """
         if json:
             import json
-        from ..configuration import Configuration
         return_list = []
         if not self.__ENTERPRISE_GENERATED_DATA_JSON:
-            self.__ENTERPRISE_GENERATED_DATA_JSON = Configuration.get_data(Configuration.config_data.get('generated_attck_json'))
+            self.__ENTERPRISE_GENERATED_DATA_JSON = Configuration.get_data('generated_attck_json')
         for item in self.__ENTERPRISE_GENERATED_DATA_JSON['techniques']:
             if 'command_list' in item:
                 if item['command_list']:
